<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta name="referrer" content="no-referrer" />
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
    <title>Hallo</title>
    <link href="/static/favicon.ico" rel="shortcut icon">
    <link rel="stylesheet" type="text/css" href="/static/css/index.css">
</head>
<body>
    <h1 class="title">
        <span style="color: crimson;">H</span>
        <span style="color: blueviolet">a</span>
        <span style="color: coral">l</span>
        <span style="color: coral">l</span>
        <span style="color: blue">o</span>
    </h1>
    <p class="content">{{ brief }}</p>
</body>
</html>